#include "conf.h"
#include "reg.h"
#include "h.h"
#include "rsc.h"
#include <stdlib.h>
#include <stdio.h>
#include "adb.h"

const int DEFAULT_LISTEN_PORT = 8080;

char block_filename[256] = "adb.cfg";
bool block_filename_used = false;
bool auto_save = false;
bool do_wnd_abort = false;
bool show_log = false;
bool show_all = false;
bool use_proxy = false;
int proxy_port = 3128;
char proxy_hostname[256] = "proxy";
bool allow_nonlocal = false;
int listen_port = DEFAULT_LISTEN_PORT;
bool auto_update = false;

const char reg_subtree_key[] = "Software\\miri\\adbuster";
const char auto_save_key[] = "adbuster_autosave";
const char block_filename_key[] = "adbuster_filename";
const char show_log_key[] = "adbuster_showlog";
const char proxy_use_key[] = "adbuster_use_proxy";
const char proxy_host_key[] = "adbuster_proxy_host";
const char proxy_port_key[] = "adbuster_proxy_port";
const char allow_nonlocal_key[] = "adbuster_allow_nonlocal";
const char listen_port_key[] = "adbuster_listen_port";
const char auto_update_key[] = "adbuster_auto_update";

void LoadConf()
{
   auto_save = get_bool_key(reg_subtree_key, auto_save_key);
   show_log = get_bool_key(reg_subtree_key, show_log_key);
   get_string_key(reg_subtree_key, block_filename_key, block_filename, sizeof(block_filename));
   use_proxy = get_bool_key(reg_subtree_key, proxy_use_key);
   get_string_key(reg_subtree_key, proxy_host_key, proxy_hostname, sizeof(proxy_hostname));
   proxy_port = get_int_key(reg_subtree_key, proxy_port_key);
   allow_nonlocal = get_bool_key(reg_subtree_key, allow_nonlocal_key);
   listen_port = get_int_key(reg_subtree_key, listen_port_key);
   if (!listen_port)
     listen_port = DEFAULT_LISTEN_PORT;
   auto_update = get_bool_key(reg_subtree_key, auto_update_key);
}

void SaveConf()
{
   set_bool_key(reg_subtree_key, auto_save_key, auto_save);
   set_bool_key(reg_subtree_key, show_log_key, show_log);
   set_string_key(reg_subtree_key, block_filename_key, block_filename);		    
   set_bool_key(reg_subtree_key, proxy_use_key, use_proxy);
   set_string_key(reg_subtree_key, proxy_host_key, proxy_hostname);
   set_int_key(reg_subtree_key, proxy_port_key, proxy_port);
   set_bool_key(reg_subtree_key, allow_nonlocal_key, allow_nonlocal);
   set_int_key(reg_subtree_key, listen_port_key, listen_port);
   set_bool_key(reg_subtree_key, auto_update_key, auto_update);
}

BOOL CALLBACK ConfDlgProc(HWND hDlg, UINT uMsg, WPARAM wParam, LPARAM)
{
   if (uMsg == WM_COMMAND) {
      if (LOWORD(wParam) == IDCANCEL)
	;
      else if (LOWORD(wParam) == IDOK) {
	 use_proxy = SendMessage(GetDlgItem(hDlg, ID_CONF_PROXYUSE), BM_GETCHECK, 0, 0);
	 SendMessage(GetDlgItem(hDlg, ID_CONF_PROXYHOST), WM_GETTEXT, 255, (LPARAM) proxy_hostname);
	 char buf[256];
	 SendMessage(GetDlgItem(hDlg, ID_CONF_PROXYPORT), WM_GETTEXT, 10, (LPARAM) buf);
	 proxy_port = atoi(buf);
	 allow_nonlocal = SendMessage(GetDlgItem(hDlg, ID_CONF_NONLOCAL), BM_GETCHECK, 0, 0);
	 SendMessage(GetDlgItem(hDlg, ID_CONF_LISTPORT), WM_GETTEXT, 10, (LPARAM) buf);
	 int l2 = atoi(buf);
	 if (l2 && l2 != listen_port) {
	   listen_port = l2;
	   listen_port_changed = true;
	 }
	 auto_update = SendMessage(GetDlgItem(hDlg, ID_CONF_AUTOUPDATE), BM_GETCHECK, 0, 0);
	 SaveConf();
      } else
	return false;
      EnableWindow(hwnd, true);
      DestroyWindow(hDlg);
      hdlg = 0;
      return false;
   }
   return false;
}

void ShowConfDlg()
{
   hdlg = CreateDialog(hInstance, "confDLG", hwnd, (DLGPROC) ConfDlgProc);
   SendMessage(GetDlgItem(hdlg, ID_CONF_PROXYUSE), BM_SETCHECK, use_proxy, 0);
   SendMessage(GetDlgItem(hdlg, ID_CONF_PROXYHOST), WM_SETTEXT, 255, (LPARAM) proxy_hostname);
   char buf[256];
   sprintf(buf, "%d", proxy_port);
   SendMessage(GetDlgItem(hdlg, ID_CONF_PROXYPORT), WM_SETTEXT, 10, (LPARAM) buf);
   SendMessage(GetDlgItem(hdlg, ID_CONF_NONLOCAL), BM_SETCHECK, allow_nonlocal, 0);
   sprintf(buf, "%d", listen_port);
   SendMessage(GetDlgItem(hdlg, ID_CONF_LISTPORT), WM_SETTEXT, 10, (LPARAM) buf);
   SendMessage(GetDlgItem(hdlg, ID_CONF_AUTOUPDATE), BM_SETCHECK, auto_update, 0);  
   ShowWindow(hdlg, SW_NORMAL);
   UpdateWindow(hdlg);
   EnableWindow(hwnd, false);
}
